You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by ac...@apache.org on 2019/08/07 13:10:39 UTC

[camel] 07/20: CAMEL-13792 - Rename components to default names, Camel-netty4 to camel-netty - Fixed Camel-ganglia test

This is an automated email from the ASF dual-hosted git repository.

acosentino pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git

commit 24b727c851c27519704d18f2636fdeab4979d5c8
Author: Andrea Cosentino <an...@gmail.com>
AuthorDate: Wed Aug 7 12:45:23 2019 +0200

    CAMEL-13792 - Rename components to default names, Camel-netty4 to camel-netty - Fixed Camel-ganglia test
---
 .../apache/camel/component/ganglia/GangliaProtocolV30CamelTest.java   | 4 ++--
 .../apache/camel/component/ganglia/GangliaProtocolV31CamelTest.java   | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/components/camel-ganglia/src/test/java/org/apache/camel/component/ganglia/GangliaProtocolV30CamelTest.java b/components/camel-ganglia/src/test/java/org/apache/camel/component/ganglia/GangliaProtocolV30CamelTest.java
index abd1667..af734c2 100644
--- a/components/camel-ganglia/src/test/java/org/apache/camel/component/ganglia/GangliaProtocolV30CamelTest.java
+++ b/components/camel-ganglia/src/test/java/org/apache/camel/component/ganglia/GangliaProtocolV30CamelTest.java
@@ -59,7 +59,7 @@ import static org.apache.camel.component.ganglia.GangliaConstants.METRIC_UNITS;
 
 /**
  * {@code GangliaProtocolV30CamelTest} is not shipped with an embedded gmond
  * agent. The gmond agent is mocked with the help of camel-netty4 codecs and a
  * mock endpoint. As underlying UDP packets are not guaranteed to be delivered,
  * loose assertions are performed.
  */
@@ -140,7 +140,7 @@ public class GangliaProtocolV30CamelTest extends CamelGangliaTestSupport {
     protected RouteBuilder createRouteBuilder() {
         return new RouteBuilder() {
             public void configure() {
-                from("netty4:udp://localhost:" + getTestPort() + "/?decoders=#protocolV30Decoder").to(mockGmond);
+                from("netty:udp://localhost:" + getTestPort() + "/?decoders=#protocolV30Decoder").to(mockGmond);
             }
         };
     }
@@ -59,7 +59,7 @@ import static org.apache.camel.component.ganglia.GangliaConstants.METRIC_UNITS;
 /**
  * {@code GangliaProtocolV30CamelTest} is not shipped with an embedded gmond
- * agent. The gmond agent is mocked with the help of camel-netty4 codecs and a
+ * agent. The gmond agent is mocked with the help of camel-netty codecs and a
  * mock endpoint. As underlying UDP packets are not guaranteed to be delivered,
  * loose assertions are performed.
diff --git a/components/camel-ganglia/src/test/java/org/apache/camel/component/ganglia/GangliaProtocolV31CamelTest.java b/components/camel-ganglia/src/test/java/org/apache/camel/component/ganglia/GangliaProtocolV31CamelTest.java
index c0f4fa0..c6eb815 100644
--- a/components/camel-ganglia/src/test/java/org/apache/camel/component/ganglia/GangliaProtocolV31CamelTest.java
+++ b/components/camel-ganglia/src/test/java/org/apache/camel/component/ganglia/GangliaProtocolV31CamelTest.java
@@ -66,7 +66,7 @@ import static org.apache.camel.component.ganglia.GangliaConstants.METRIC_UNITS;
 
 /**
  * {@code GangliaProtocolV31CamelTest} is not shipped with an embedded gmond
  * agent. The gmond agent is mocked with the help of camel-netty4 codecs and a
  * mock endpoint. As underlying UDP packets are not guaranteed to be delivered,
  * loose assertions are performed.
  */
@@ -218,7 +218,7 @@ public class GangliaProtocolV31CamelTest extends CamelGangliaTestSupport {
     protected RouteBuilder createRouteBuilder() {
         return new RouteBuilder() {
             public void configure() {
-                from("netty4:udp://localhost:" + getTestPort() + "/?decoders=#protocolV31Decoder").to(mockGmond);
+                from("netty:udp://localhost:" + getTestPort() + "/?decoders=#protocolV31Decoder").to(mockGmond);
             }
         };
     }
@@ -66,7 +66,7 @@ import static org.apache.camel.component.ganglia.GangliaConstants.METRIC_UNITS;
 /**
  * {@code GangliaProtocolV31CamelTest} is not shipped with an embedded gmond
- * agent. The gmond agent is mocked with the help of camel-netty4 codecs and a
+ * agent. The gmond agent is mocked with the help of camel-netty codecs and a
  * mock endpoint. As underlying UDP packets are not guaranteed to be delivered,
  * loose assertions are performed.